@@ -10,7 +10,6 @@ use YAML;
 use File::Spec;
 use File::Path;
 use File::Find;
-use VIM::Packager::Record;
 
 our $VERSION = 0.0.1;
 my  $VERBOSE = 1;
@@ -18,10 +17,9 @@ my  $VERBOSE = 1;
 =head1 SYNOPSIS
 
     $ vim-packager build 
-    $ make -f Makefile.vimp
-
+    $ make 
         # auto install dependency 
-    $ make install -f Makefile.vimp
+    $ make install
 
 =head1 Constants
 
@@ -122,7 +120,7 @@ sub new {
 
     push @$main, q|.PHONY: all install clean uninstall help upload link|;
     
-    my $filelist = $self->make_filelist( $meta->{libpath} || LIBPATH );
+    my $filelist = $self->make_filelist();
 
     $makefile->{filelist} = $filelist;
 
@@ -140,42 +138,34 @@ sub new {
     $self->section_deps( $main );
     $self->section_link( $main , $filelist );
 
-    new_section $main => 'manifest';
-    add_st $main => q|$(NOECHO) $(ECHO) ".git" > MANIFEST.SKIP|;
-    add_st $main => q|$(NOECHO) $(ECHO) ".svn" >> MANIFEST.SKIP|;
-    add_st $main => q|$(NOECHO) $(ECHO) ".*.tar.gz" >> MANIFEST.SKIP|;
-    add_st $main => q|$(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Manifest=mkmanifest -e 'mkmanifest'|;
+    # -----------
 
-    new_section $main => 'dist' , qw(manifest);
-    add_st $main => q|$(TAR) $(TARFLAGS) $(DISTNAME).tar.gz $(TO_INST_VIMS) $(META_FILE) $(README) `cat MANIFEST`|;
+    new_section $main => 'manifest';
+    add_st $main => q|$(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Manifest=mkmanifest -e 'mkmanifest'|;
+    add_st $main => q|$(NOECHO) $(TOUCH) MANIFEST.SKIP|;
+
+    new_section $main => 'dist';
+    add_st $main => q|$(TAR) $(TARFLAGS) $(DISTNAME).tar.gz $(TO_INST_VIMS) $(META_FILE) $(README)|;
 	add_noop_st $main;
 
     new_section $main => 'help';
     add_st $main => q|perldoc VIM::Packager|;
 
     new_section $main => 'uninstall';
-    add_st $main => q|$(NOECHO) $(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Installer=uninstall  |
-            . q| -e 'uninstall()' $(NAME)|;
+    for( values %$filelist ) {
+        add_st $main => q|$(RM_F) | . $_ ;
+    }
 
     # XXX: prompt user to uninstall depedencies
-    new_section $main => 'reinstall' , qw(uninstall install);
-    add_noop_st $main;
 
     new_section $main => 'upload' , qw(dist);
     add_st $main => q|$(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Uploader=upload -e 'upload()' |
                 . multi_line qw|$(PWD)/$(DISTNAME).tar.gz $(VIM_VERSION) $(VERSION) $(SCRIPT_ID)|;
 
     new_section $main => 'clean';
+    add_st $main      => multi_line q|$(RM)|, qw(pure_install install-deps);
     add_st $main      => q|$(MV) $(FIRST_MAKEFILE) $(MAKEFILE_OLD)|;
-    add_st $main      => q|$(RM) *.tar.gz|;
 
-    new_section $main => 'bump';
-    add_st $main => q|$(NOECHO) $(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Installer=bump_version -e 'bump_version()' |;
-    add_st $main => q|sh -c 'vim-packager build'|;  # rebuild
-    add_st $main => q|sh -c 'make upload -f Makefile.vimp'|;
-
-    new_section $main => 'release' , qw(bump);
-    add_noop_st $main;
 
     $self->generate_makefile( [
             { meta   => \@meta_section },
@@ -249,9 +239,14 @@ sub section_pure_install {
         }
     }
     else {
+
         add_st $main =>
             q|$(NOECHO) $(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Installer=install|
-            . q| -e 'install()' $(NAME) $(VIMS_TO_RUNT) $(BIN_TO_RUNT)|;
+            . q| -e 'install()' $(VIMS_TO_RUNT) |;
+
+        add_st $main =>
+            q|$(NOECHO) $(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Installer=install|
+            . q| -e 'install()' $(BIN_TO_RUNT) |;
     }
 }
 
@@ -269,21 +264,17 @@ sub section_deps {
 
     if( $self->{cmd}->{pure} ) {
         print "You are making a pure makefile that doesn't depend on perl module.\n";
-        print "We are going to skip dependency section.\n";
+        print "We are going to skip deps section.\n";
         add_noop_st $main;
         return;
     }
 
-    my $requires = $self->check_dependency( $self->meta );
-    my %unsatisfied      = %{ $requires->{unsat} };
-    my %nonversion_unsat = %{ $requires->{nonversion_unsat} };
 
-    # grep out the non-version package requires from those unsatisfied infomation
-    # which is an array ref because it's a file list.
-    my @pkgs_nonversion = keys %nonversion_unsat;
+    my %unsatisfied = $self->check_dependency( $self->meta );
+    my @pkgs_nonversion = grep { ref($unsatisfied{$_}) eq 'ARRAY' } sort keys %unsatisfied;
     for my $pkgname ( @pkgs_nonversion ) {
         my @nonversion_params = map {  ( $_->{target} , $_->{from} ) } 
-            map { @{ $nonversion_unsat{ $_ } } } $pkgname ;
+            map { @{ $unsatisfied{ $_ } } } $pkgname ;
 
         add_st $main => multi_line q|$(NOECHO) $(FULLPERL) $(PERLFLAGS)|
                     . qq| -MVIM::Packager::Installer=install_deps_remote |
@@ -292,24 +283,10 @@ sub section_deps {
 
     }
 
-    # XXX: grep git repo deps from upstream ... zzz
-    # packages with version specified.
-    my @pkgs_version = keys %unsatisfied;
+    my @pkgs_version = grep {  ref($unsatisfied{$_}) ne 'ARRAY' } sort keys %unsatisfied;
     if( @pkgs_version > 0 ) {
-        my @pkgs_git_repo = grep { $unsatisfied{ $_ }->{git_repo} } @pkgs_version;
-        for my $pkg ( @pkgs_git_repo ) {
-            my $dep = $unsatisfied{ $pkg };
-            
-            my $v = $dep->{version};
-            add_st $main => q|$(NOECHO) $(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Installer=install_deps_from_git |
-                . qq| -e 'install_deps_from_git()' @{[ $dep->{git_repo} ]} $v|;
-        }
-
-        my @pkgs_version = grep { ! $unsatisfied{ $_ }->{git_repo} } @pkgs_version;
-        
         add_st $main => q|$(NOECHO) $(FULLPERL) $(PERLFLAGS) -MVIM::Packager::Installer=install_deps  |
-                . qq| -e 'install_deps()' '@{[ join ",",@pkgs_version ]}' |
-                        if @pkgs_version > 0;
+                . qq| -e 'install_deps()' '@{[ join ",",@pkgs_version ]}' |;
     }
 }
 
@@ -341,9 +318,9 @@ sub generate_makefile {
     my $sections = shift;
     
 
-    print "Write to Makefile.vimp\n";
+    print "Write to Makefile.\n";
 
-    open my $fh , ">" , 'Makefile.vimp';
+    open my $fh , ">" , 'Makefile';
     print $fh <<'END';
 # VIM::Packager::MakeMaker
 #
@@ -367,6 +344,7 @@ END
     print "DONE\n";
 }
 
+
 sub meta_section {
     my $self = shift;
     my $meta = shift;
@@ -413,11 +391,7 @@ sub config_section {
     $configs{LN_SF}     ||= 'ln -svf';
     $configs{PWD}       ||= '`pwd`';
     $configs{CP}        ||= 'cp -v';
-
-    $configs{README} ||= '';
-    $configs{README} .= ' README'     if -e 'README';
-    $configs{README} .= ' README.mkd' if -e 'README.mkd';
-
+    $configs{README}    ||= 'README README.*';
     $configs{META_FILE} ||= VIM::Packager::MetaReader->find_meta_file();
 
     $configs{FIRST_MAKEFILE} ||= 'Makefile';
@@ -442,8 +416,7 @@ sub file_section {
 
     my @to_install = keys %$filelist;
 
-    add_macro \@section , VIMLIB => $meta->{libpath} || LIBPATH;
-
+    add_macro \@section , VIMLIB => LIBPATH;
     add_macro \@section , VIMMETA => VIM::Packager::MetaReader::find_meta_file();
 
     add_macro \@section , TO_INST_VIMS => multi_line @to_install ;
@@ -466,10 +439,6 @@ sub file_section {
     return @section;
 }
 
-=head2 get_installed_pkgs
-
-=cut
-
 sub get_installed_pkgs {
     my ($self, $dir ) = @_;
 
@@ -493,14 +462,6 @@ sub get_installed_pkgs {
     return @pkg_record_files;
 }
 
-
-
-=head2 check_dependency
-
-pass meta object and check dependency.
-
-=cut
-
 sub check_dependency {
     my $self = shift;
     my $meta = shift;
@@ -509,49 +470,35 @@ sub check_dependency {
     my @pkg_records = $self->get_installed_pkgs($record_dir);
 
     my %unsatisfied = ();
-    my %nonversion_unsat = ();
-
     for my $dep ( @{ $meta->{dependency} } ) {
 
         if ( defined $dep->{version} ) {
-            my ( $prereq, $required_version, $version_op , $git_repo ) 
-                        = @$dep{qw(name version op git_repo)};
+            my ( $prereq, $required_version, $version_op ) = @$dep{qw(name version op)};
+
+            my $installed_files;  # XXX: get installed files of prerequire plugins
 
             # XXX: check if prerequire plugin is installed. 
-            #      try to get installed package record 
+            #      try to get installed package record by vimana manager 
             #      or just look into file and parse the version
-            my $pr_version = undef ;
+            my $pr_version = 0 ; $pr_version = parse_version( $installed_files ) if $installed_files;  
 
-            my $found = VIM::Packager::Record->find( $prereq );
-            if( $found ) {
-                my $r = VIM::Packager::Record->read( $found );
-                $pr_version = $r->{meta}->{version};
-                print "Found Installed Package: $prereq \n";
-                print "Version: $pr_version\n";
-            }
-            else {
-                my $installed_files; # get installed files here
-                $pr_version = parse_version( $installed_files ) if( $installed_files );
-            }
-
-            if( ! $pr_version ) {
+            if( ! $installed_files ) {
                 warn sprintf "Warning: prerequisite %s - %s not found.\n", 
-                    $prereq, $required_version;
-                $unsatisfied{ $prereq } = $dep;
+                $prereq, $required_version;
+
+                $unsatisfied{ $prereq } = 'not installed';
             }
             elsif ( eval "$pr_version $version_op $required_version"  ) {
                 warn sprintf "Warning: prerequisite %s - %s not found. We have %s.\n",
-                    $prereq, $required_version, $pr_version;
-
-                $unsatisfied{ $prereq } = $dep;
+                    $prereq, $required_version, ($pr_version || 'unknown version') ;
+                $unsatisfied{ $prereq } = $pr_version;
             }
-
         }
         else {
             # if we can not detect installed package version
             # here is the other way to install dependencies.
             my ( $prereq , $require_files ) = ( $dep->{name}  , $dep->{required_files} );
-            $nonversion_unsat{ $prereq } = $require_files; 
+            $unsatisfied{ $prereq } = $require_files; 
 
             # XXX: grep out ?
             for ( @$require_files ) {
@@ -571,19 +518,11 @@ sub check_dependency {
 
     }
 
-    return {
-        unsat => \%unsatisfied,
-        nonversion_unsat => \%nonversion_unsat,
-    };
+    return %unsatisfied;
 }
 
-sub possible_runtime_dir { qw(autoload after syntax ftplugin ftdetect compiler plugin macros colors doc) }
 
-=head2 init_vim_dir_macro
 
-init vim dir macro
-
-=cut
 
 sub init_vim_dir_macro {
     my $self = shift;
@@ -591,7 +530,7 @@ sub init_vim_dir_macro {
     $dir_configs{ VIM_BASEDIR } = $ENV{VIM_BASEDIR} || vim_rtp_home();
     $dir_configs{ VIM_AFTERBASE_DIR} = $ENV{VIM_AFTERBASE_DIR}  || File::Spec->join( $dir_configs{VIM_BASEDIR} , 'after' );
 
-    for my $sub ( possible_runtime_dir() ) {
+    for my $sub ( qw(after syntax ftplugin compiler plugin macros colors) ) {
         my $path_name = 'VIM_' . uc($sub) . '_DIR';
         my $after_path_name = 'VIM_AFTER_' . uc($sub) . '_DIR';
         $dir_configs{$path_name} = $ENV{$path_name}
@@ -604,39 +543,19 @@ sub init_vim_dir_macro {
 }
 
 
-=head2 make_filelist
-
-if install_dirs is given , then we should record:
-
-    autoload/zzz.vim
-    plugin/xxx.vim
-
-if not , then we should find files from F<vimlib/>
-
-    TO_INSTALL=$(VIM_BASEDIR)/plugin/xxx.vim
-        \ $(VIM_BASEDIR)/autoload/zzz.vim
-
-=cut
-
 sub make_filelist {
-    my ( $self, $base_prefix ) = @_;
+    my $self = shift;
 
     my %install = ();
+    my $base_prefix = LIBPATH;
 
     # my $prefix = File::Spec->join($ENV{HOME} , '.vim');
     my $prefix = '$(VIM_BASEDIR)';
-
-    my @search_dir = ( ( $base_prefix eq '.' or $base_prefix eq './' ) 
-                ?  possible_runtime_dir()
-                :  $base_prefix );
-    
-
     File::Find::find( sub {
         return unless -f $_;
         return if /\#/;
         return if /~$/;             # emacs temp files
         return if /,v$/;            # RCS files
-        return if /\.(git|svn)/;          # skip .git
         return if m{\.swp$};        # vim swap files
 
         my $src = File::Spec->catfile( $File::Find::dir , $_ );
@@ -646,11 +565,35 @@ sub make_filelist {
         $target = File::Spec->catfile( $prefix , $target );
 
         $install{ $src } = $target;
-        print "Added $src to file list\n";
-    } , grep { -e $_ } @search_dir );
+    } , $base_prefix );
     return \%install;
 }
 
+# XXX: implement me
+sub full_setup {
+    my @attrib_help = qw(
+        AUTHOR
+        NAME
+        CONFIGURE
+        INST_AUTOLOAD
+        INST_PLUGIN
+        INST_SYNTAX
+
+        INST_AFTER_PLUGIN
+        INST_AFTER_AUTOLOAD
+        INST_AFTER_FTPLUGIN
+    );
+
+    my @MM_Sections = qw(
+        all
+        dist
+        depend
+        install
+        clean
+        force
+    );
+}
+
 
 # XXX:
 # parse version from vim runtime path files
